==> 3.0.0.tar.gz: sharpdevelop/src/Tools/NUnit/nunit-console/AssemblyInfo.cs <==
﻿// ****************************************************************
// This is free software licensed under the NUnit license. You
// may obtain a copy of the license as well as information regarding
// copyright ownership at http://nunit.org/?p=license&r=2.4.
// 

using System.Reflection;

//
// Common Information about all NUnit assemblies is controlled through the following 
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
//
[assembly: AssemblyTitle("Extended NUnit console runner")]
[assembly: AssemblyDescription("NUnit-console extended by Daniel Grunwald and Matt Ward to support writing test results to a file as results are known")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("NUnit.org")]
[assembly: AssemblyProduct("NUnit")]
[assembly: AssemblyCopyright("Copyright (C) 2002-2007 Charlie Poole.\r\n" +
                             "Copyright (C) 2002-2004 James W. Newkirk, Michael C. Two, Alexei A. Vorontsov.\r\n" +
                             "Copyright (C) 2000-2003 Philip Craig.\r\n" +
                             "Copyright (C) 2006 Daniel Grunwald.\r\n" +
                             "Copyright (C) 2006-2008 Matt Ward.\r\n" +
                             "All Rights Reserved.")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]		

//
// Version information for an assembly consists of the following four values:
//
//      Major Version
//      Minor Version 
//      Build Number
//      Revision
//
// You can specify all the values or you can default the Revision and Build Numbers 
// by using the '*' as shown below:

[assembly: AssemblyVersion("2.4.8")]

==> 4.3.0.tar.gz: sharpdevelop/src/Tools/NUnit/nunit-console/AssemblyInfo.cs <==
﻿// ****************************************************************
// This is free software licensed under the NUnit license. You
// may obtain a copy of the license as well as information regarding
// copyright ownership at http://nunit.org.
// ****************************************************************

using System.Reflection;

//
// Common Information about all NUnit assemblies is controlled through the following 
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
//
[assembly: AssemblyTitle("Extended NUnit console runner")]
[assembly: AssemblyDescription("NUnit-console extended by Daniel Grunwald and Matt Ward to support writing test results to a file as results are known")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("NUnit.org")]
[assembly: AssemblyProduct("NUnit")]
[assembly: AssemblyCopyright("Copyright (C) 2002-2012 Charlie Poole.\r\n" +
                             "Copyright (C) 2002-2004 James W. Newkirk, Michael C. Two, Alexei A. Vorontsov.\r\n" +
                             "Copyright (C) 2000-2002 Philip Craig.\r\n" +
                             "Copyright (C) 2006 Daniel Grunwald.\r\n" +
                             "Copyright (C) 2006-2008 Matt Ward.\r\n" +
                               "All Rights Reserved.")]
[assembly: AssemblyTrademark("NUnit is a trademark of NUnit.org")]
[assembly: AssemblyCulture("")]		

//
// Version information for an assembly consists of the following four values:
//
//      Major Version
//      Minor Version 
//      Build Number
//      Revision
//
// You can specify all the values or you can default the Revision and Build Numbers 
// by using the '*' as shown below:

[assembly: AssemblyVersion("2.6.2")]
[assembly: AssemblyInformationalVersion("2.6.2")]
